@@ -10,28 +10,28 @@ FILEPATH = os.path.dirname(os.path.abspath(__file__))
 
 
 DEFAULT_MODELS = {
-    Category.Vehicle: f"{FILEPATH}/cars/Aston_martin.stl",
-    Category.Pedestrian: f"{FILEPATH}/pedestrians/default_male.stl",
-    Category.Cyclist: f"{FILEPATH}/cyclists/bicycle2.stl",
-    Category.TrafficCone: f"{FILEPATH}/traffic_cones/cone.stl",
-    SubCategory.Car: f"{FILEPATH}/cars/Aston_martin.stl",
-    SubCategory.Van: f"{FILEPATH}/vans/volkswagen_transporter.stl",
-    SubCategory.Bus: f"{FILEPATH}/buses/ShortSchoolBus.stl",
-    SubCategory.Truck: f"{FILEPATH}/trucks/Truck2.stl",
-    SubCategory.Motorcycle: f"{FILEPATH}/motorcycles/kawaski.stl",
+    Category.Vehicle: os.path.join(FILEPATH, "cars", "Aston_martin.stl"),
+    Category.Pedestrian: os.path.join(FILEPATH, "pedestrians", "default_male.stl"),
+    Category.Cyclist: os.path.join(FILEPATH, "cyclists", "bicycle2.stl"),
+    Category.TrafficCone: os.path.join(FILEPATH, "traffic_cones", "cone.stl"),
+    SubCategory.Car: os.path.join(FILEPATH, "cars", "Aston_martin.stl"),
+    SubCategory.Van: os.path.join(FILEPATH, "vans", "volkswagen_transporter.stl"),
+    SubCategory.Bus: os.path.join(FILEPATH, "buses", "ShortSchoolBus.stl"),
+    SubCategory.Truck: os.path.join(FILEPATH, "trucks", "Truck2.stl"),
+    SubCategory.Motorcycle: os.path.join(FILEPATH, "motorcycles", "kawaski.stl"),
 }
 
 
 DIRECTORIES = {
-    Category.Vehicle: f"{FILEPATH}/cars",
-    Category.Pedestrian: f"{FILEPATH}/pedestrians",
-    Category.Cyclist: f"{FILEPATH}/cyclists",
-    Category.TrafficCone: f"{FILEPATH}/traffic_cones",
-    SubCategory.Car: f"{FILEPATH}/cars",
-    SubCategory.Van: f"{FILEPATH}/vans",
-    SubCategory.Bus: f"{FILEPATH}/buses",
-    SubCategory.Truck: f"{FILEPATH}/trucks",
-    SubCategory.Motorcycle: f"{FILEPATH}/motorcycles",
+    Category.Vehicle: os.path.join(FILEPATH, "cars"),
+    Category.Pedestrian: os.path.join(FILEPATH, "pedestrians"),
+    Category.Cyclist: os.path.join(FILEPATH, "cyclists"),
+    Category.TrafficCone: os.path.join(FILEPATH, "traffic_cones"),
+    SubCategory.Car: os.path.join(FILEPATH, "cars"),
+    SubCategory.Van: os.path.join(FILEPATH, "vans"),
+    SubCategory.Bus: os.path.join(FILEPATH, "buses"),
+    SubCategory.Truck: os.path.join(FILEPATH, "trucks"),
+    SubCategory.Motorcycle: os.path.join(FILEPATH, "motorcycles"),
 }
 
 
