@@ -26,6 +26,8 @@ class Viewer:
         self.set_resolution(resolution)
         self.set_background(background)
 
+        self.callbacks: List[callable] = []
+
         self.camera = Camera(self)
         self.interactor = Interactor(self, mouse_camera_interactions)
         self.hud = Hud(self, position=(50, 50))
@@ -41,9 +43,11 @@ class Viewer:
     def set_background(self, color=Tuple[float, float, float]):
         self.renderer.SetBackground(*color)
 
+    def set_callback(self, callback: callable):
+        self.callbacks.append(callback)
+
     def update(self):
-        self.interactor.update()
-        self.hud.update()
+        [callback() for callback in self.callbacks]
         self.renderWindow.Render()
         self.__clear_actors()
 
